@@ -1,14 +1,35 @@
+#
+# This file is part of Pod-Weaver-Section-Support
+#
+# This software is copyright (c) 2014 by Apocalypse.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
+use strict; use warnings;
 package Pod::Weaver::Section::Support;
-$Pod::Weaver::Section::Support::VERSION = '1.009';
+# git description: release-1.005-6-g89972c5
+$Pod::Weaver::Section::Support::VERSION = '1.006';
+BEGIN {
+  $Pod::Weaver::Section::Support::AUTHORITY = 'cpan:APOCAL';
+}
+
 # ABSTRACT: Add a SUPPORT section to your POD
 
 use Moose 1.03;
-use PPIx::DocumentName;
+use Moose::Autobox 0.10;
 
 with 'Pod::Weaver::Role::Section' => { -version => '3.100710' };
 
 sub mvp_multivalue_args { qw( websites irc bugs_content email_content irc_content repository_content websites_content ) }
 
+#pod =attr all_modules
+#pod
+#pod Enable this if you want to add the SUPPORT section to all the modules in a dist, not only the main one.
+#pod
+#pod The default is false.
+#pod
+#pod =cut
 
 has all_modules => (
 	is => 'ro',
@@ -16,6 +37,13 @@ has all_modules => (
 	default => 0,
 );
 
+#pod =attr perldoc
+#pod
+#pod Specify if you want the paragraph explaining about perldoc to be displayed or not.
+#pod
+#pod The default is true.
+#pod
+#pod =cut
 
 has perldoc => (
 	is => 'ro',
@@ -23,6 +51,20 @@ has perldoc => (
 	default => 1,
 );
 
+#pod =attr bugs
+#pod
+#pod Specify the bugtracker you want to use. You can use the CPAN RT tracker or your own, specified in the metadata.
+#pod
+#pod Valid options are: "rt", "metadata", or "none"
+#pod
+#pod If you pick the "rt" option, this module will generate a predefined block of text explaining how to use the RT system.
+#pod
+#pod If you pick the "metadata" option, this module will check the L<Dist::Zilla> metadata for the bugtracker to display. Be sure
+#pod to verify that your metadata contains both 'web' and 'mailto' keys if you want to use them in the content!
+#pod
+#pod The default is "rt".
+#pod
+#pod =cut
 
 {
 	use Moose::Util::TypeConstraints 1.01;
@@ -36,6 +78,15 @@ has perldoc => (
 	no Moose::Util::TypeConstraints;
 }
 
+#pod =attr bugs_content
+#pod
+#pod Specify the content for the bugs section.
+#pod
+#pod Please put the "{EMAIL}" and "{WEB}" placeholders somewhere!
+#pod
+#pod The default is a sufficient explanation (see L</SUPPORT>).
+#pod
+#pod =cut
 
 has bugs_content => (
 	is => 'ro',
@@ -50,6 +101,37 @@ EOPOD
 	},
 );
 
+#pod =attr websites
+#pod
+#pod Specify what website links you want to see. This is an array, and you can pick any combination. You can also
+#pod specify it as a comma-delimited string. The ordering of the options are important, as they are reflected in
+#pod the final POD.
+#pod
+#pod Valid options are: "none", "metacpan", "search", "rt", "anno", "ratings", "forum", "kwalitee", "testers", "testmatrix", "deps" and "all".
+#pod
+#pod The default is "all".
+#pod
+#pod 	# Where the links go to:
+#pod 	metacpan	- http://metacpan.org/release/$dist
+#pod 	search		- http://search.cpan.org/dist/$dist
+#pod 	rt		- https://rt.cpan.org/Public/Dist/Display.html?Name=$dist
+#pod 	anno		- http://annocpan.org/dist/$dist
+#pod 	ratings		- http://cpanratings.perl.org/d/$dist
+#pod 	forum		- http://cpanforum.com/dist/$dist
+#pod 	kwalitee	- http://cpants.perl.org/dist/overview/$dist
+#pod 	testers		- http://cpantesters.org/distro/$first_char/$dist
+#pod 	testmatrix	- http://matrix.cpantesters.org/?dist=$dist
+#pod 	deps		- http://deps.cpantesters.org/?module=$module
+#pod
+#pod 	# in weaver.ini
+#pod 	[Support]
+#pod 	websites = search
+#pod 	websites = forum
+#pod 	websites = testers , testmatrix
+#pod
+#pod P.S. If you know other websites that I should include here, please let me know!
+#pod
+#pod =cut
 
 # TODO how do I Moosify this into a fancy type system where it coerces from CSV strings and bla bla?
 has websites => (
@@ -58,6 +140,13 @@ has websites => (
 	default => sub { [ 'all' ] },
 );
 
+#pod =attr websites_content
+#pod
+#pod Specify the content to be displayed before the website list.
+#pod
+#pod The default is a sufficient explanation (see L</SUPPORT>).
+#pod
+#pod =cut
 
 has websites_content => (
 	is => 'ro',
@@ -71,6 +160,31 @@ EOPOD
 	},
 );
 
+#pod =attr irc
+#pod
+#pod Specify an IRC server/channel/nick for online support. You can specify as many networks/channels as you want.
+#pod The ordering of the options are important, as they are reflected in the final POD.
+#pod
+#pod You specify a network, then a list of channels/nicks to ask for support. There are two ways to format the string:
+#pod
+#pod 	servername.com,#room,nick
+#pod 	irc://servername.com/#room
+#pod
+#pod The default is none.
+#pod
+#pod 	# in weaver.ini
+#pod 	[Support]
+#pod 	irc = irc.home.org, #support, supportbot
+#pod 	irc = irc.acme.com, #acmecorp, #acmehelp, #acmenewbies
+#pod
+#pod You can also add the irc information in the distribution metadata via L<Dist::Zilla::Plugin::Metadata>.
+#pod Valid keys are 'x_irc' or 'IRC' but you have to use the irc:// format to retain compatibility with the rest of the ecosystem.
+#pod
+#pod 	# in dist.ini
+#pod 	[Metadata]
+#pod 	x_irc = irc://irc.perl.org/#perl
+#pod
+#pod =cut
 
 has irc => (
 	is => 'ro',
@@ -78,6 +192,13 @@ has irc => (
 	default => sub { [ ] },
 );
 
+#pod =attr irc_content
+#pod
+#pod Specify the content to be displayed before the irc network/channel list.
+#pod
+#pod The default is a sufficient explanation (see L</SUPPORT>).
+#pod
+#pod =cut
 
 has irc_content => (
 	is => 'ro',
@@ -93,6 +214,23 @@ EOPOD
 	},
 );
 
+#pod =attr repository_link
+#pod
+#pod Specify which url to use when composing the external link.
+#pod The value corresponds to the repository meta resources (for dzil v3 with CPAN Meta v2).
+#pod
+#pod Valid options are: "url", "web", "both", or "none".
+#pod
+#pod "both" will include links to both the "url" and "web" in separate POD paragraphs.
+#pod
+#pod "none" will skip the repository item entirely.
+#pod
+#pod The default is "both".
+#pod
+#pod An error will be thrown if a specified link is not found
+#pod because if you said that you wanted it you probably expect it to be there.
+#pod
+#pod =cut
 
 {
 	use Moose::Util::TypeConstraints 1.01;
@@ -106,6 +244,13 @@ EOPOD
 	no Moose::Util::TypeConstraints;
 }
 
+#pod =attr repository_content
+#pod
+#pod Specify the content to be displayed before the link to the source code repository.
+#pod
+#pod The default is a sufficient explanation (see L</SUPPORT>).
+#pod
+#pod =cut
 
 has repository_content => (
 	is => 'ro',
@@ -120,6 +265,15 @@ EOPOD
 	},
 );
 
+#pod =attr email
+#pod
+#pod Specify an email address here so users can contact you directly for help.
+#pod
+#pod If you supply a string without '@' in it, we assume it is a PAUSE id and mangle it into 'USER at cpan.org'.
+#pod
+#pod The default is none.
+#pod
+#pod =cut
 
 has email => (
 	is => 'ro',
@@ -127,6 +281,15 @@ has email => (
 	default => undef,
 );
 
+#pod =attr email_content
+#pod
+#pod Specify the content for the email section.
+#pod
+#pod Please put the "{EMAIL}" placeholder somewhere!
+#pod
+#pod The default is a sufficient explanation ( see L</SUPPORT>).
+#pod
+#pod =cut
 
 has email_content => (
 	is => 'ro',
@@ -150,9 +313,10 @@ sub weave_section {
 		return if $zilla->main_module->name ne $input->{filename};
 	}
 
-	# Add the stopwords so the spell checker won't complain!
-	# TODO make this smarter so it loads only the stopwords we need for specific sections... ohwell
-	push @{ $document->children }, Pod::Elemental::Element::Pod5::Region->new( {
+	$document->children->push(
+		# Add the stopwords so the spell checker won't complain!
+		# TODO make this smarter so it loads only the stopwords we need for specific sections... ohwell
+		Pod::Elemental::Element::Pod5::Region->new( {
 			format_name => 'stopwords',
 			is_pod => 1,
 			content => '',
@@ -161,19 +325,20 @@ sub weave_section {
 					content => join( " ", qw( cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan ) ),
 				} ),
 			],
-	} ),
-	Pod::Elemental::Element::Nested->new( {
+		} ),
+		Pod::Elemental::Element::Nested->new( {
 			command => 'head1',
 			content => 'SUPPORT',
 			children => [
-				$self->_add_perldoc( $input->{ppi_document} ),
+				$self->_add_perldoc( $zilla ),
 				$self->_add_websites( $zilla ),
 				$self->_add_email( $zilla ),
 				$self->_add_irc( $zilla ),
 				$self->_add_bugs( $zilla, $input->{'distmeta'} ),
 				$self->_add_repo( $zilla ),
 			],
-	} );
+		} ),
+	);
 }
 
 sub _add_email {
@@ -250,13 +415,17 @@ sub _add_bugs {
 }
 
 sub _add_perldoc {
-	my( $self, $ppi_doc ) = @_;
+	my( $self, $zilla ) = @_;
 
 	# Do we have anything to do?
 	return () if ! $self->perldoc;
 
-	# Get the name for the module
-	my $module = PPIx::DocumentName->extract( $ppi_doc );
+	# Don't use $zilla->name as some dists' name is different from the actual module...
+	# TODO what if user specified $self->all_modules( 1 )? should this use the current filename?
+	my $main_module = $zilla->main_module->name;
+	$main_module =~ s|^lib/||i;
+	$main_module =~ s/\.pm$//;
+	$main_module =~ s|/|::|g;
 
 	# TODO add language detection as per RT#63726
 
@@ -271,7 +440,7 @@ EOPOD
 
 			} ),
 			Pod::Elemental::Element::Pod5::Verbatim->new( {
-				content => "  perldoc $module",
+				content => "  perldoc $main_module",
 			} ),
 		],
 	} );
@@ -283,23 +452,24 @@ sub _add_irc {
 
 	my @irc;
 
-	# thanks to https://metacpan.org/about/metadata for the info!
-	if ( scalar @{ $self->irc } ) {
-		$self->log( 'IRC was set twice: in the metadata and in this plugin, overriding the metadata!' ) if exists $zilla->distmeta->{'x_IRC'};
-		@irc = @{ $self->irc };
-	} elsif ( exists $zilla->distmeta->{'x_IRC'} ) {
-		my $x_irc = $zilla->distmeta->{'x_IRC'};
-		if ( ref $x_irc ) { # handle the newer url/web nested spec
-			$x_irc = $x_irc->{'url'};
-		}
+	# Did the user specify it as metadata in Dist::Zilla?
+	if ( exists $zilla->distmeta->{'x_irc'} or exists $zilla->distmeta->{'IRC'} ) {
+		die 'You specified the IRC information twice: in the metadata and in this plugin, please pick one!' if scalar @{ $self->irc };
+
+		# we follow the irc://irc.perl.org/#roomname format
+		my $x_irc = exists $zilla->distmeta->{'x_irc'} ? $zilla->distmeta->{'x_irc'} : $zilla->distmeta->{'IRC'};
 		if ( $x_irc =~ m|^irc://([^/]+)/(.+)$| ) {
 			push( @irc, "$1,$2" );
 		} else {
-			$self->log( "Error: the IRC metadata needs to be in the proper format: 'irc://servername.com/#room' but yours was: $x_irc" );
-			return ();
+			die "The IRC metadata needs to be in the proper format: 'irc://servername.com/#room' but yours was: $x_irc";
 		}
 	} else {
-		return ();
+		# Do we have anything to do?
+		if ( scalar @{ $self->irc } ) {
+			@irc = @{ $self->irc };
+		} else {
+			return ();
+		}
 	}
 
 	my @networks;
@@ -479,14 +649,14 @@ sub _add_websites {
 
 	# sanity check
 	foreach my $type ( @{ $self->websites } ) {
-		if ( $type !~ /^(?:metacpan|search|rt|anno|ratings|kwalitee|testers|testmatrix|deps|all)$/i ) {
+		if ( $type !~ /^(?:metacpan|search|rt|anno|ratings|forum|kwalitee|testers|testmatrix|deps|all)$/i ) {
 			$self->log_fatal( "Unknown website type: $type" );
 		}
 	}
 
 	# Set the default ordering for "all"
 	if ( grep { $_ eq 'all' } @{ $self->websites } ) { ## no critic ( BuiltinFunctions::ProhibitBooleanGrep )
-		@{ $self->websites } = qw( metacpan search rt anno ratings kwalitee testers testmatrix deps );
+		@{ $self->websites } = qw( metacpan search rt anno ratings forum kwalitee testers testmatrix deps );
 	}
 
 	# Make the website links!
@@ -533,7 +703,7 @@ sub _add_websites_metacpan {
 	return _make_item( 'MetaCPAN', <<"EOF" );
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<https://metacpan.org/release/$dist>
+L<http://metacpan.org/release/$dist>
 EOF
 }
 
@@ -577,13 +747,23 @@ L<http://cpanratings.perl.org/d/$dist>
 EOF
 }
 
+sub _add_websites_forum {
+	my $dist = shift;
+
+	return _make_item( 'CPAN Forum', <<"EOF" );
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/$dist>
+EOF
+}
+
 sub _add_websites_kwalitee {
 	my $dist = shift;
 
 	return _make_item( 'CPANTS', <<"EOF" );
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.cpanauthors.org/dist/$dist>
+L<http://cpants.cpanauthors.org/dist/overview/$dist>
 EOF
 }
 
@@ -593,7 +773,7 @@ sub _add_websites_testers {
 	my $first_char = substr( $dist, 0, 1 );
 
 	return _make_item( 'CPAN Testers', <<"EOF" );
-The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/$first_char/$dist>
 EOF
@@ -646,13 +826,19 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Apocalypse Alex Fredric Kent Peters Randy Stauner cpan testmatrix url
+annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
+placeholders metacpan dist dzil repo
+
+=for Pod::Coverage weave_section mvp_multivalue_args
+
 =head1 NAME
 
 Pod::Weaver::Section::Support - Add a SUPPORT section to your POD
 
 =head1 VERSION
 
-version 1.009
+  This document describes v1.006 of Pod::Weaver::Section::Support - released October 25, 2014 as part of Pod-Weaver-Section-Support.
 
 =head1 DESCRIPTION
 
@@ -709,17 +895,18 @@ Specify what website links you want to see. This is an array, and you can pick a
 specify it as a comma-delimited string. The ordering of the options are important, as they are reflected in
 the final POD.
 
-Valid options are: "none", "metacpan", "search", "rt", "anno", "ratings", "kwalitee", "testers", "testmatrix", "deps" and "all".
+Valid options are: "none", "metacpan", "search", "rt", "anno", "ratings", "forum", "kwalitee", "testers", "testmatrix", "deps" and "all".
 
 The default is "all".
 
 	# Where the links go to:
-	metacpan	- https://metacpan.org/release/$dist
+	metacpan	- http://metacpan.org/release/$dist
 	search		- http://search.cpan.org/dist/$dist
 	rt		- https://rt.cpan.org/Public/Dist/Display.html?Name=$dist
 	anno		- http://annocpan.org/dist/$dist
 	ratings		- http://cpanratings.perl.org/d/$dist
-	kwalitee	- http://cpants.perl.org/dist/$dist
+	forum		- http://cpanforum.com/dist/$dist
+	kwalitee	- http://cpants.perl.org/dist/overview/$dist
 	testers		- http://cpantesters.org/distro/$first_char/$dist
 	testmatrix	- http://matrix.cpantesters.org/?dist=$dist
 	deps		- http://deps.cpantesters.org/?module=$module
@@ -727,7 +914,7 @@ The default is "all".
 	# in weaver.ini
 	[Support]
 	websites = search
-	websites = metacpan
+	websites = forum
 	websites = testers , testmatrix
 
 P.S. If you know other websites that I should include here, please let me know!
@@ -756,11 +943,11 @@ The default is none.
 	irc = irc.acme.com, #acmecorp, #acmehelp, #acmenewbies
 
 You can also add the irc information in the distribution metadata via L<Dist::Zilla::Plugin::Metadata>.
-The key is 'x_IRC' but you have to use the irc:// format to retain compatibility with the rest of the ecosystem.
+Valid keys are 'x_irc' or 'IRC' but you have to use the irc:// format to retain compatibility with the rest of the ecosystem.
 
 	# in dist.ini
 	[Metadata]
-	x_IRC = irc://irc.perl.org/#perl
+	x_irc = irc://irc.perl.org/#perl
 
 =head2 irc_content
 
@@ -806,36 +993,6 @@ Please put the "{EMAIL}" placeholder somewhere!
 
 The default is a sufficient explanation ( see L</SUPPORT>).
 
-=head1 VERSION
-
-version 1.009
-
-=for stopwords dist dzil repo
-
-=for Pod::Coverage weave_section mvp_multivalue_args
-
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Apocalyptic.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/pod-weaver-section-support/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -857,7 +1014,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<https://metacpan.org/release/Pod-Weaver-Section-Support>
+L<http://metacpan.org/release/Pod-Weaver-Section-Support>
 
 =item *
 
@@ -873,7 +1030,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Support>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Pod-Weaver-Section-Support>
 
 =item *
 
@@ -893,17 +1050,25 @@ L<http://cpanratings.perl.org/d/Pod-Weaver-Section-Support>
 
 =item *
 
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Pod-Weaver-Section-Support>
+
+=item *
+
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.cpanauthors.org/dist/Pod-Weaver-Section-Support>
+L<http://cpants.cpanauthors.org/dist/overview/Pod-Weaver-Section-Support>
 
 =item *
 
 CPAN Testers
 
-The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/P/Pod-Weaver-Section-Support>
 
@@ -925,10 +1090,43 @@ L<http://deps.cpantesters.org/?module=Pod::Weaver::Section::Support>
 
 =back
 
+=head2 Email
+
+You can email the author of this module at C<APOCAL at cpan.org> asking for help with any problems you have.
+
+=head2 Internet Relay Chat
+
+You can get live help by using IRC ( Internet Relay Chat ). If you don't know what IRC is,
+please read this excellent guide: L<http://en.wikipedia.org/wiki/Internet_Relay_Chat>. Please
+be courteous and patient when talking to us, as we might be busy or sleeping! You can join
+those networks/channels and get help:
+
+=over 4
+
+=item *
+
+irc.perl.org
+
+You can connect to the server at 'irc.perl.org' and join this channel: #perl-help then talk to this person for help: Apocalypse.
+
+=item *
+
+irc.freenode.net
+
+You can connect to the server at 'irc.freenode.net' and join this channel: #perl then talk to this person for help: Apocal.
+
+=item *
+
+irc.efnet.org
+
+You can connect to the server at 'irc.efnet.org' and join this channel: #perl then talk to this person for help: Ap0cal.
+
+=back
+
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-pod-weaver-section-support at rt.cpan.org>, or through
-the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Pod-Weaver-Section-Support>. You will be automatically notified of any
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Pod-Weaver-Section-Support>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -937,8 +1135,63 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/perl-pod-weaver-section-support>
+L<https://github.com/apocalypse/perl-pod-weaver-section-support>
 
-  git clone https://github.com/shlomif/perl-pod-weaver-section-support
+  git clone git://github.com/apocalypse/perl-pod-weaver-section-support.git
+
+=head1 AUTHOR
+
+Apocalypse <APOCAL@cpan.org>
+
+=head2 CONTRIBUTORS
+
+=for stopwords Alex Peters Kent Fredric Randy Stauner
+
+=over 4
+
+=item *
+
+Alex Peters <lxp@cpan.org>
+
+=item *
+
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
+Randy Stauner <randy@magnificent-tears.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Apocalypse.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
+=head1 DISCLAIMER OF WARRANTY
+
+THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
+APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
+HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY
+OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
+THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM
+IS WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
+ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS
+THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
+GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
+USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
+DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
+PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS),
+EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
